"use strict";

var _react = _interopRequireDefault(require("react"));

var _enzyme = require("enzyme");

var _FlipCard = _interopRequireDefault(require("../FlipCard"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(source, true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(source).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

it('renders without crashing', function () {
  (0, _enzyme.shallow)(_react.default.createElement(_FlipCard.default, {
    frontContent: "test",
    backContent: "back"
  }));
});
it('renders content of the front and back card', function () {
  var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_FlipCard.default, {
    frontContent: "test",
    backContent: "back"
  }));
  expect(wrapper.find('.card').length).toBe(1);
  expect(wrapper.find('.card__face--front').length).toBe(1);
  expect(wrapper.find('.card__face--back').length).toBe(1);
});
it('renders content as a React component', function () {
  var FakeComponent = function FakeComponent() {
    return _react.default.createElement("div", {
      className: "fake-component"
    }, "This is a component");
  };

  var wrapper = (0, _enzyme.mount)(_react.default.createElement(_FlipCard.default, {
    frontContent: _react.default.createElement(FakeComponent, null),
    backContent: _react.default.createElement(FakeComponent, null)
  }));
  expect(wrapper.find('.fake-component').length).toBe(2);
});
it('should include card__flipped when the card is flipped', function () {
  var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_FlipCard.default, {
    flipped: true,
    onCardClick: jest.fn(),
    backContent: "This is a front",
    backCardStyle: {
      background: 'blue'
    },
    frontContent: "This is a front",
    frontCardStyle: {
      background: 'red'
    }
  }));
  expect(wrapper.find('.card__flipped').length).toBe(1);
});
it('should include card__flipped--horizontal when horizontal is true', function () {
  var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_FlipCard.default, {
    horizontal: true,
    flipped: true,
    onCardClick: jest.fn(),
    backContent: "This is a front",
    backCardStyle: {
      background: 'blue'
    },
    frontContent: "This is a front",
    frontCardStyle: {
      background: 'red'
    }
  }));
  expect(wrapper.find('.card__flipped--horizontal').length).toBe(2);
});
test('clicking on the card calls onCardClick', function () {
  var props = _objectSpread({}, _FlipCard.default.defaultProps, {
    onCardClick: jest.fn()
  });

  var wrapper = (0, _enzyme.mount)(_react.default.createElement(_FlipCard.default, props));
  expect(props.onCardClick).not.toBeCalled();
  expect(wrapper.find('.card').length).toBe(1);
  wrapper.find('.card').simulate('click');
  expect(props.onCardClick).toBeCalled();
});